==> hs-cairo-0.12.3.1_1.tbz: lib/ghc-7.4.1/cabal/cairo-0.12.3.1/register.sh <==
#!/bin/sh
echo 'name: cairo
version: 0.12.3.1
id: cairo-0.12.3.1-72943041ac0a8f5f7b9a3859e6d71fe1

license: BSD3
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the Cairo library.
description: Cairo is a library to render high quality vector graphics. There
             exist various backends that allows rendering to Gtk windows, PDF,
             PS, PNG and SVG documents, amongst others.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules: Graphics.Rendering.Cairo
                 Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types
                 Graphics.Rendering.Cairo.Internal
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/cairo-0.12.3.1
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/cairo-0.12.3.1
              /usr/local/lib
hs-libraries: HScairo-0.12.3.1
extra-libraries: z cairo
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/cairo
              /usr/local/include/glib-2.0 /usr/local/include/pixman-1
              /usr/local/include/freetype2 /usr/local/include/libpng15
includes:
depends: array-0.4.0.0-59d1cc0e7979167b002f021942d60f46
         base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         bytestring-0.9.2.1-6ff76798e80a342ff74a1c8bcb3f4124
         mtl-2.1.1-801101765c9185fec3b8dbd5355f5550
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/cairo-0.12.3.1/html/cairo.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/cairo-0.12.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-cairo-0.12.4_1.tbz: lib/ghc-7.4.2/cabal/cairo-0.12.4/register.sh <==
#!/bin/sh
echo 'name: cairo
version: 0.12.4
id: cairo-0.12.4-2d47e71a1445815024ecedde0f6622ab

license: BSD3
copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the Cairo library.
description: Cairo is a library to render high quality vector graphics. There
             exist various backends that allows rendering to Gtk windows, PDF,
             PS, PNG and SVG documents, amongst others.
category: Graphics
author: Axel Simon, Duncan Coutts
exposed: True
exposed-modules: Graphics.Rendering.Cairo
                 Graphics.Rendering.Cairo.Matrix Graphics.Rendering.Cairo.Types
                 Graphics.Rendering.Cairo.Internal
hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                Graphics.Rendering.Cairo.Internal.Drawing.Paths
                Graphics.Rendering.Cairo.Internal.Drawing.Patterns
                Graphics.Rendering.Cairo.Internal.Drawing.Text
                Graphics.Rendering.Cairo.Internal.Drawing.Transformations
                Graphics.Rendering.Cairo.Internal.Fonts.FontOptions
                Graphics.Rendering.Cairo.Internal.Surfaces.Image
                Graphics.Rendering.Cairo.Internal.Surfaces.PNG
                Graphics.Rendering.Cairo.Internal.Surfaces.Surface
                Graphics.Rendering.Cairo.Internal.Utilities
                Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                Graphics.Rendering.Cairo.Internal.Surfaces.PS
                Graphics.Rendering.Cairo.Internal.Surfaces.SVG
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/cairo-0.12.4
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/cairo-0.12.4
              /usr/local/lib
hs-libraries: HScairo-0.12.4
extra-libraries: z cairo
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/cairo
              /usr/local/include/glib-2.0 /usr/local/include/pixman-1
              /usr/local/include/freetype2 /usr/local/include/libpng15
includes:
depends: array-0.4.0.0-0b6c5ca7e879a14d110ca4c001dd9297
         base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         bytestring-0.9.2.1-4cc8a513193316dfe32ba33f47609c9d
         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/cairo-0.12.4/html/cairo.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/cairo-0.12.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
